==> cargo-binstall-1.16.0-1.src.tar.gz: cargo-binstall-1.16.0/crates/detect-targets/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.61](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.60...detect-targets-v0.1.61) - 2025-09-06

### Other

- *(deps)* bump the deps group with 2 updates ([#2298](https://github.com/cargo-bins/cargo-binstall/pull/2298))

## [0.1.60](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.59...detect-targets-v0.1.60) - 2025-08-30

### Other

- *(deps)* bump the deps group across 1 directory with 2 updates ([#2286](https://github.com/cargo-bins/cargo-binstall/pull/2286))

## [0.1.59](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.58...detect-targets-v0.1.59) - 2025-08-24

### Other

- update Cargo.lock dependencies

## [0.1.58](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.57...detect-targets-v0.1.58) - 2025-08-22

### Other

- update Cargo.lock dependencies

## [0.1.57](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.56...detect-targets-v0.1.57) - 2025-08-09

### Other

- Fix unused Result in DesiredTargets::auto_detect ([#2250](https://github.com/cargo-bins/cargo-binstall/pull/2250))

## [0.1.56](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.55...detect-targets-v0.1.56) - 2025-08-01

### Other

- Fix race condition of DesiredTargets ([#2238](https://github.com/cargo-bins/cargo-binstall/pull/2238))

## [0.1.55](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.54...detect-targets-v0.1.55) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.69](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.68...detect-targets-v0.1.69) - 2025-11-15

### Other

- update Cargo.lock dependencies

## [0.1.68](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.67...detect-targets-v0.1.68) - 2025-11-09

### Other

- update Cargo.lock dependencies

## [0.1.67](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.66...detect-targets-v0.1.67) - 2025-11-02

### Other

- update Cargo.lock dependencies

## [0.1.66](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.65...detect-targets-v0.1.66) - 2025-11-01

### Other

- update Cargo.lock dependencies

## [0.1.65](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.64...detect-targets-v0.1.65) - 2025-10-24

### Other

- update Cargo.lock dependencies

## [0.1.64](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.63...detect-targets-v0.1.64) - 2025-10-10

### Other

- update Cargo.lock dependencies

## [0.1.63](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.62...detect-targets-v0.1.63) - 2025-09-26

### Other

- update Cargo.lock dependencies

## [0.1.62](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.61...detect-targets-v0.1.62) - 2025-09-14

### Other

- update Cargo.lock dependencies

## [0.1.54](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.53...detect-targets-v0.1.54) - 2025-06-22

### Other

- update Cargo.lock dependencies

## [0.1.53](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.52...detect-targets-v0.1.53) - 2025-06-21

### Other

- Fix glibc detection on Fedora ([#2205](https://github.com/cargo-bins/cargo-binstall/pull/2205))
- *(deps)* bump windows-sys from 0.59.0 to 0.60.2 in the deps group ([#2196](https://github.com/cargo-bins/cargo-binstall/pull/2196))

## [0.1.52](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.51...detect-targets-v0.1.52) - 2025-06-10

### Other

- update Cargo.lock dependencies

## [0.1.51](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.50...detect-targets-v0.1.51) - 2025-06-06

### Other

- update Cargo.lock dependencies

## [0.1.50](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.49...detect-targets-v0.1.50) - 2025-05-30

### Other

- update Cargo.lock dependencies

## [0.1.49](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.48...detect-targets-v0.1.49) - 2025-05-16

### Other

- update Cargo.lock dependencies

## [0.1.48](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.47...detect-targets-v0.1.48) - 2025-05-07

### Other

- Fix glibc detection on ubuntu 24.02 ([#2143](https://github.com/cargo-bins/cargo-binstall/pull/2143))

## [0.1.47](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.46...detect-targets-v0.1.47) - 2025-04-05

### Other

- update Cargo.lock dependencies

## [0.1.46](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.45...detect-targets-v0.1.46) - 2025-03-19

### Other

- Fix clippy warnings for detect-targets and binstalk-downloader ([#2098](https://github.com/cargo-bins/cargo-binstall/pull/2098))

## [0.1.45](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.44...detect-targets-v0.1.45) - 2025-03-15

### Other

- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.1.44](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.43...detect-targets-v0.1.44) - 2025-03-07

### Other

- Fix detect-targets musl fallback for android and alpine ([#2076](https://github.com/cargo-bins/cargo-binstall/pull/2076))

## [0.1.43](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.42...detect-targets-v0.1.43) - 2025-02-28

### Other

- update Cargo.lock dependencies

## [0.1.42](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.41...detect-targets-v0.1.42) - 2025-02-22

### Other

- update Cargo.lock dependencies

## [0.1.41](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.40...detect-targets-v0.1.41) - 2025-02-15

### Other

- update Cargo.lock dependencies

## [0.1.40](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.39...detect-targets-v0.1.40) - 2025-02-11

### Other

- update Cargo.lock dependencies

## [0.1.39](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.38...detect-targets-v0.1.39) - 2025-02-04

### Other

- update Cargo.lock dependencies

## [0.1.38](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.37...detect-targets-v0.1.38) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.1.37](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.36...detect-targets-v0.1.37) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.1.36](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.35...detect-targets-v0.1.36) - 2025-01-11

### Other

- update Cargo.lock dependencies

## [0.1.35](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.34...detect-targets-v0.1.35) - 2025-01-04

### Other

- update Cargo.lock dependencies

## [0.1.34](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.33...detect-targets-v0.1.34) - 2024-12-28

### Other

- update Cargo.lock dependencies

## [0.1.33](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.32...detect-targets-v0.1.33) - 2024-12-14

### Other

- update Cargo.lock dependencies

## [0.1.32](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.31...detect-targets-v0.1.32) - 2024-12-07

### Other

- update Cargo.lock dependencies

## [0.1.31](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.30...detect-targets-v0.1.31) - 2024-11-29

### Other

- update Cargo.lock dependencies

## [0.1.30](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.29...detect-targets-v0.1.30) - 2024-11-23

### Other

- update Cargo.lock dependencies

## [0.1.29](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.28...detect-targets-v0.1.29) - 2024-11-18

### Other

- update Cargo.lock dependencies

## [0.1.28](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.27...detect-targets-v0.1.28) - 2024-11-09

### Other

- update Cargo.lock dependencies

## [0.1.27](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.26...detect-targets-v0.1.27) - 2024-11-05

### Other

- update Cargo.lock dependencies

## [0.1.26](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.25...detect-targets-v0.1.26) - 2024-11-02

### Other

- update Cargo.lock dependencies

## [0.1.25](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.24...detect-targets-v0.1.25) - 2024-10-25

### Other

- update Cargo.lock dependencies

## [0.1.24](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.23...detect-targets-v0.1.24) - 2024-10-12

### Other

- update Cargo.lock dependencies

## [0.1.23](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.22...detect-targets-v0.1.23) - 2024-10-04

### Other

- update Cargo.lock dependencies

## [0.1.22](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.21...detect-targets-v0.1.22) - 2024-09-22

### Other

- update Cargo.lock dependencies

## [0.1.21](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.20...detect-targets-v0.1.21) - 2024-09-06

### Other
- update Cargo.lock dependencies

## [0.1.20](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.19...detect-targets-v0.1.20) - 2024-08-25

### Other
- update Cargo.lock dependencies

## [0.1.19](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.18...detect-targets-v0.1.19) - 2024-08-10

### Other
- update Cargo.lock dependencies

## [0.1.18](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.17...detect-targets-v0.1.18) - 2024-08-04

### Other
- *(deps)* bump the deps group across 1 directory with 2 updates ([#1859](https://github.com/cargo-bins/cargo-binstall/pull/1859))

==> cargo-binstall-1.16.2-1.src.tar.gz: cargo-binstall-1.16.2/crates/detect-targets/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.61](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.60...detect-targets-v0.1.61) - 2025-09-06

### Other

- *(deps)* bump the deps group with 2 updates ([#2298](https://github.com/cargo-bins/cargo-binstall/pull/2298))

## [0.1.60](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.59...detect-targets-v0.1.60) - 2025-08-30

### Other

- *(deps)* bump the deps group across 1 directory with 2 updates ([#2286](https://github.com/cargo-bins/cargo-binstall/pull/2286))

## [0.1.59](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.58...detect-targets-v0.1.59) - 2025-08-24

### Other

- update Cargo.lock dependencies

## [0.1.58](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.57...detect-targets-v0.1.58) - 2025-08-22

### Other

- update Cargo.lock dependencies

## [0.1.57](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.56...detect-targets-v0.1.57) - 2025-08-09

### Other

- Fix unused Result in DesiredTargets::auto_detect ([#2250](https://github.com/cargo-bins/cargo-binstall/pull/2250))

## [0.1.56](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.55...detect-targets-v0.1.56) - 2025-08-01

### Other

- Fix race condition of DesiredTargets ([#2238](https://github.com/cargo-bins/cargo-binstall/pull/2238))

## [0.1.55](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.54...detect-targets-v0.1.55) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.71](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.70...detect-targets-v0.1.71) - 2025-11-23

### Other

- update Cargo.lock dependencies

## [0.1.70](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.69...detect-targets-v0.1.70) - 2025-11-21

### Other

- update Cargo.lock dependencies

## [0.1.69](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.68...detect-targets-v0.1.69) - 2025-11-15

### Other

- update Cargo.lock dependencies

## [0.1.68](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.67...detect-targets-v0.1.68) - 2025-11-09

### Other

- update Cargo.lock dependencies

## [0.1.67](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.66...detect-targets-v0.1.67) - 2025-11-02

### Other

- update Cargo.lock dependencies

## [0.1.66](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.65...detect-targets-v0.1.66) - 2025-11-01

### Other

- update Cargo.lock dependencies

## [0.1.65](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.64...detect-targets-v0.1.65) - 2025-10-24

### Other

- update Cargo.lock dependencies

## [0.1.64](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.63...detect-targets-v0.1.64) - 2025-10-10

### Other

- update Cargo.lock dependencies

## [0.1.63](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.62...detect-targets-v0.1.63) - 2025-09-26

### Other

- update Cargo.lock dependencies

## [0.1.62](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.61...detect-targets-v0.1.62) - 2025-09-14

### Other

- update Cargo.lock dependencies

## [0.1.54](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.53...detect-targets-v0.1.54) - 2025-06-22

### Other

- update Cargo.lock dependencies

## [0.1.53](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.52...detect-targets-v0.1.53) - 2025-06-21

### Other

- Fix glibc detection on Fedora ([#2205](https://github.com/cargo-bins/cargo-binstall/pull/2205))
- *(deps)* bump windows-sys from 0.59.0 to 0.60.2 in the deps group ([#2196](https://github.com/cargo-bins/cargo-binstall/pull/2196))

## [0.1.52](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.51...detect-targets-v0.1.52) - 2025-06-10

### Other

- update Cargo.lock dependencies

## [0.1.51](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.50...detect-targets-v0.1.51) - 2025-06-06

### Other

- update Cargo.lock dependencies

## [0.1.50](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.49...detect-targets-v0.1.50) - 2025-05-30

### Other

- update Cargo.lock dependencies

## [0.1.49](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.48...detect-targets-v0.1.49) - 2025-05-16

### Other

- update Cargo.lock dependencies

## [0.1.48](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.47...detect-targets-v0.1.48) - 2025-05-07

### Other

- Fix glibc detection on ubuntu 24.02 ([#2143](https://github.com/cargo-bins/cargo-binstall/pull/2143))

## [0.1.47](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.46...detect-targets-v0.1.47) - 2025-04-05

### Other

- update Cargo.lock dependencies

## [0.1.46](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.45...detect-targets-v0.1.46) - 2025-03-19

### Other

- Fix clippy warnings for detect-targets and binstalk-downloader ([#2098](https://github.com/cargo-bins/cargo-binstall/pull/2098))

## [0.1.45](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.44...detect-targets-v0.1.45) - 2025-03-15

### Other

- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.1.44](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.43...detect-targets-v0.1.44) - 2025-03-07

### Other

- Fix detect-targets musl fallback for android and alpine ([#2076](https://github.com/cargo-bins/cargo-binstall/pull/2076))

## [0.1.43](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.42...detect-targets-v0.1.43) - 2025-02-28

### Other

- update Cargo.lock dependencies

## [0.1.42](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.41...detect-targets-v0.1.42) - 2025-02-22

### Other

- update Cargo.lock dependencies

## [0.1.41](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.40...detect-targets-v0.1.41) - 2025-02-15

### Other

- update Cargo.lock dependencies

## [0.1.40](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.39...detect-targets-v0.1.40) - 2025-02-11

### Other

- update Cargo.lock dependencies

## [0.1.39](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.38...detect-targets-v0.1.39) - 2025-02-04

### Other

- update Cargo.lock dependencies

## [0.1.38](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.37...detect-targets-v0.1.38) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.1.37](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.36...detect-targets-v0.1.37) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.1.36](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.35...detect-targets-v0.1.36) - 2025-01-11

### Other

- update Cargo.lock dependencies

## [0.1.35](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.34...detect-targets-v0.1.35) - 2025-01-04

### Other

- update Cargo.lock dependencies

## [0.1.34](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.33...detect-targets-v0.1.34) - 2024-12-28

### Other

- update Cargo.lock dependencies

## [0.1.33](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.32...detect-targets-v0.1.33) - 2024-12-14

### Other

- update Cargo.lock dependencies

## [0.1.32](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.31...detect-targets-v0.1.32) - 2024-12-07

### Other

- update Cargo.lock dependencies

## [0.1.31](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.30...detect-targets-v0.1.31) - 2024-11-29

### Other

- update Cargo.lock dependencies

## [0.1.30](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.29...detect-targets-v0.1.30) - 2024-11-23

### Other

- update Cargo.lock dependencies

## [0.1.29](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.28...detect-targets-v0.1.29) - 2024-11-18

### Other

- update Cargo.lock dependencies

## [0.1.28](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.27...detect-targets-v0.1.28) - 2024-11-09

### Other

- update Cargo.lock dependencies

## [0.1.27](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.26...detect-targets-v0.1.27) - 2024-11-05

### Other

- update Cargo.lock dependencies

## [0.1.26](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.25...detect-targets-v0.1.26) - 2024-11-02

### Other

- update Cargo.lock dependencies

## [0.1.25](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.24...detect-targets-v0.1.25) - 2024-10-25

### Other

- update Cargo.lock dependencies

## [0.1.24](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.23...detect-targets-v0.1.24) - 2024-10-12

### Other

- update Cargo.lock dependencies

## [0.1.23](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.22...detect-targets-v0.1.23) - 2024-10-04

### Other

- update Cargo.lock dependencies

## [0.1.22](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.21...detect-targets-v0.1.22) - 2024-09-22

### Other

- update Cargo.lock dependencies

## [0.1.21](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.20...detect-targets-v0.1.21) - 2024-09-06

### Other
- update Cargo.lock dependencies

## [0.1.20](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.19...detect-targets-v0.1.20) - 2024-08-25

### Other
- update Cargo.lock dependencies

## [0.1.19](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.18...detect-targets-v0.1.19) - 2024-08-10

### Other
- update Cargo.lock dependencies

## [0.1.18](https://github.com/cargo-bins/cargo-binstall/compare/detect-targets-v0.1.17...detect-targets-v0.1.18) - 2024-08-04

### Other
- *(deps)* bump the deps group across 1 directory with 2 updates ([#1859](https://github.com/cargo-bins/cargo-binstall/pull/1859))
